@@ -2,28 +2,16 @@ import hashlib
 import math
 import time
 from datetime import datetime, timezone
-from enum import Enum
 from python_graphql_client import GraphqlClient
 
+from .const import API_KEY, API_SECRET, ENDPOINT
 from .exception_classes import LoginError
+from .status import NormalStatus, YesOrNo
 
 from . import gql_mutations as gm
 from . import gql_queries as gq
 
 
-class NormalStatus(Enum):
-    ENABLE = "ENABLE"
-    DISABLE = "DISABLE"
-    UNKNOWN__ = "UNKNOWN__"
-
-
-class WatchOnlineStatus(Enum):
-    UNKNOWN = "UNKNOWN"
-    ONLINE = "ONLINE"
-    OFFLINE = "OFFLINE"
-    UNKNOWN__ = "UNKNOWN__"
-
-
 class GQLHandler:
     def __init__(self, countryPhoneNumber: str, phoneNumber: str, password: str, userLang: str, timeZone: str):
         # init vars
@@ -35,12 +23,11 @@ class GQLHandler:
         self.countryPhoneNumber = countryPhoneNumber
         self.phoneNumber = phoneNumber
         self.passwordMD5 = hashlib.md5(password.encode()).hexdigest()
-        self.API_KEY = "270072d0fb4811ebacd96f6726fbdbb1"
-        self.API_SECRET = "2d0288d0fb4811ebabfbd57e57c6ae64"
+        self._API_KEY = API_KEY
+        self._API_SECRET = API_SECRET
         self.issueDate = 0
         self.expireDate = 0
         self.userId = None
-        self.ENDPOINT = "https://api.myxplora.com/api"
         self.variables = {
             "countryPhoneNumber": self.countryPhoneNumber,
             "phoneNumber": self.phoneNumber,
@@ -53,17 +40,17 @@ class GQLHandler:
     def getRequestHeaders(self, acceptedContentType: str):
         if acceptedContentType == "" or acceptedContentType is None:
             raise Exception("acceptedContentType MUST NOT be empty!")
-        if self.API_KEY is None:
+        if self._API_KEY is None:
             raise Exception("Xplorao2o API_KEY MUST NOT be empty!")
-        if self.API_SECRET is None:
+        if self._API_SECRET is None:
             raise Exception("Xplorao2o API_SECRET MUST NOT be empty!")
         requestHeaders = {}
         if self.accessToken is None:
             # OPEN authorization
-            authorizationHeader = f"Open {self.API_KEY}:{self.API_SECRET}"
+            authorizationHeader = f"Open {self._API_KEY}:{self._API_SECRET}"
         else:
             # BEARER authorization
-            authorizationHeader = f"Bearer {self.accessToken}:{self.API_SECRET}"
+            authorizationHeader = f"Bearer {self.accessToken}:{self._API_SECRET}"
             rfc1123DateString = datetime.now(timezone.utc).strftime("%a, %d %b %Y %H:%M:%S") + " GMT"
             requestHeaders["H-Date"] = rfc1123DateString
             requestHeaders["H-Authorization"] = authorizationHeader
@@ -79,7 +66,7 @@ class GQLHandler:
         # Add Xplora® API headers
         requestHeaders = self.getRequestHeaders("application/json; charset=UTF-8")
         # create GQLClient
-        gqlClient = GraphqlClient(endpoint=self.ENDPOINT, headers=requestHeaders)
+        gqlClient = GraphqlClient(endpoint=ENDPOINT, headers=requestHeaders)
         # execute QUERY|MUTATION
         data = await gqlClient.execute_async(query=query, variables=variables)
         return data
@@ -91,7 +78,7 @@ class GQLHandler:
         return (await self.runGqlQuery_a(query, variables))
 
     async def login_a(self):
-        data = (await self.runGqlQuery_a(gm.MUTATION["tokenM"], self.variables))['data']
+        data = (await self.runGqlQuery_a(gm.SIGN_M["issueTokenM"], self.variables))['data']
         if data['issueToken'] is None:
             # Login failed.
             raise LoginError("Login to Xplora® API failed. Check your input!")
@@ -107,9 +94,9 @@ class GQLHandler:
         if self.issueToken['app'] is not None:
             # Update API_KEY and API_SECRET?
             if self.issueToken['app']['apiKey']:
-                self.API_KEY = self.issueToken['app']['apiKey']
+                self._API_KEY = self.issueToken['app']['apiKey']
             if self.issueToken['app']['apiSecret']:
-                self.API_SECRET = self.issueToken['app']['apiSecret']
+                self._API_SECRET = self.issueToken['app']['apiSecret']
         return self.issueToken
 
     async def isAdmin_a(self, ownId, query, variables, key):
@@ -128,80 +115,76 @@ class GQLHandler:
 
     async def getMyInfo_a(self):
         # Profil from login Account
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['readMyInfoQ'], {}))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.MYINFO_Q['readQ'], {}))['data']
 
     async def getContacts_a(self, ownId):
         # Contacts from ownUser
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['contactsQ'], { "uid": ownId }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['contactsQ'], { "uid": ownId }))['data']
 
     async def getWatchCount_a(self):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['watchCountQ'], {}))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['followRequestWatchCountQ'], {}))['data']
 
     async def getWatches_a(self, ownId):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['watchesQ'], { "uid": ownId }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['watchesQ'], { "uid": ownId }))['data']
 
     async def getWatchLastLocation_a(self, ownId):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['watchLastLocateQ'], { "uid": ownId }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['locateQ'], { "uid": ownId }))['data']
 
     async def trackWatch_a(self, ownId):
         # tracking time - seconds
-        res = (await self.runAuthorizedGqlQuery_a(gq.QUERY['trackWatchQ'], { "uid": ownId }))['data']
+        res = (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['trackQ'], { "uid": ownId }))['data']
         if res['trackWatch'] is not None:
             return res
         return { 'trackWatch': -1 }
 
     async def askWatchLocate_a(self, ownId):
-        res = (await self.runAuthorizedGqlQuery_a(gq.QUERY['askWatchLocateQ'], { "uid": ownId }))['data']
+        res = (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['askLocateQ'], { "uid": ownId }))['data']
         if res['askWatchLocate'] is not None:
             return res
         return { 'askWatchLocate': False }
 
     async def getAlarms_a(self, ownId):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['alarmsQ'], { "uid": ownId }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['alarmsQ'], { "uid": ownId }))['data']
 
     async def getWifi_a(self, id):
         # without function?
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['getWifiQ'], { "uid": id }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['getWifisQ'], { "uid": id }))['data']
 
     async def avatars_a(self, id):
         # without function?
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['avatarsQ'], { 'id': id }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.CAMPAIGN_Q['avatarsQ'], { 'id': id }))['data']
 
     async def unReadChatMsgCount_a(self, ownId):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['unReadChatMsgCountQ'], { 'uid': ownId }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['unReadChatMsgCountQ'], { 'uid': ownId }))['data']
 
     async def chats_a(self, ownId):
         # ownUser id
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['chatsQ'], { 'uid': ownId }))['data']
-
-    async def notice_a(self):
-        # without function?
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['noticeQ'], {}))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['chatsQ'], { 'uid': ownId }))['data']
 
     async def staticCard_a(self):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['staticCardQ'], {}))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.CARD_Q['staticQ'], {}))['data']
 
     async def campaignUserProfiles_a(self):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['CampaignUserProfilesQ'], {}))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.MYINFO_Q['campaignUserProfilesQ'], {}))['data']
 
     async def subscribedCampaign_a(self, id, needDetail=False):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['subscribedCampaignQ'], { 'uid': id, 'needDetail': needDetail }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.CAMPAIGN_Q['subscribedQ'], { 'uid': id, 'needDetail': needDetail }))['data']
 
     async def getReviewStatus_a(self, id):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['GetReviewStatusQ'], { 'uid': id }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.REVIEW_Q['getStatusQ'], { 'uid': id }))['data']
 
     async def countries_a(self):
         # Country Support
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['CountriesQ'], {}))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.UTILS_Q['countriesQ'], {}))['data']
 
     async def safeZones_a(self, ownId):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['safeZonesQ'], { 'uid': ownId }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['safeZonesQ'], { 'uid': ownId }))['data']
 
     async def safeZoneGroups_a(self):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['safeZoneGroupsQ'], {}))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['safeZoneGroupsQ'], {}))['data']
 
     async def silentTimes_a(self, ownId):
-        return (await self.runAuthorizedGqlQuery_a(gq.QUERY['silentTimesQ'], { 'uid': ownId }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gq.WATCH_Q['silentTimesQ'], { 'uid': ownId }))['data']
 
 ########## SECTION QUERY end ##########
 
@@ -209,32 +192,32 @@ class GQLHandler:
 
     async def sendText_a(self, ownId, text):
         # ownUser id
-        if (await self.runAuthorizedGqlQuery_a(gm.MUTATION['sendTextM'], { "uid": ownId, "text": text }))['data']['sendChatText'] is not None:
+        if (await self.runAuthorizedGqlQuery_a(gm.WATCH_M['sendChatTextM'], { "uid": ownId, "text": text }))['data']['sendChatText'] is not None:
             return True
         return False
 
     async def addStep_a(self, stepCount):
-        return (await self.runAuthorizedGqlQuery_a(gm.MUTATION['addStepM'], { "stepCount": stepCount }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gm.STEP_M['addM'], { "stepCount": stepCount }))['data']
 
     async def shutdown_a(self, ownId):
         # ownUser id
-        return await self.isAdmin_a(ownId, gm.MUTATION['shutdownM'], { "uid": ownId }, 'reboot')
+        return await self.isAdmin_a(ownId, gm.WATCH_M['shutdownM'], { "uid": ownId }, 'reboot')
 
     async def reboot_a(self, ownId):
         # ownUser id
-        return await self.isAdmin_a(ownId, gm.MUTATION['rebootM'], { "uid": ownId }, 'reboot')
+        return await self.isAdmin_a(ownId, gm.WATCH_M['rebootM'], { "uid": ownId }, 'reboot')
 
-    async def modifyAlert_a(self, id, YesOrNo):
+    async def modifyAlert_a(self, id, yesOrNo: YesOrNo):
         # function?
-        return await self.runAuthorizedGqlQuery_a(gm.MUTATION['modifyAlertM'], { "uid": id, "remind": YesOrNo })
+        return await self.runAuthorizedGqlQuery_a(gm.WATCH_M['modifyAlertM'], { "uid": id, "remind": yesOrNo })
 
     async def setEnableSlientTime_a(self, silentId, status: NormalStatus = NormalStatus.ENABLE.value):
-        return (await self.runAuthorizedGqlQuery_a(gm.MUTATION['setEnableSlientTimeM'], { 'silentId': silentId, 'status': status }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gm.WATCH_M['setEnableSlientTimeM'], { 'silentId': silentId, 'status': status }))['data']
 
     async def setEnableAlarmTime_a(self, alarmId, status: NormalStatus = NormalStatus.ENABLE.value):
-        return (await self.runAuthorizedGqlQuery_a(gm.MUTATION['ModifyAlarmM'], { 'alarmId': alarmId, 'status': status }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gm.WATCH_M['modifyAlarmM'], { 'alarmId': alarmId, 'status': status }))['data']
 
     async def setReadChatMsg(self, ownId, msgId, id):
-        return (await self.runAuthorizedGqlQuery_a(gm.MUTATION['setReadChatMsg'], { "uid": ownId, 'msgId': msgId, 'id': id }))['data']
+        return (await self.runAuthorizedGqlQuery_a(gm.WATCH_M['setReadChatMsgM'], { "uid": ownId, 'msgId': msgId, 'id': id }))['data']
 
 ########## SECTION MUTATION end ##########
